summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKevin K Wong <kevin.k.wong@intel.com>2015-05-22 00:11:34 -0700
committerChromeOS Commit Bot <chromeos-commit-bot@chromium.org>2015-05-23 02:41:35 +0000
commit18ff8dca1b3e1122b6e527fa1dda3a76846bd3a2 (patch)
treed5a50b60b29dfe8acae260907f08925db4953a50
parent42faec21244d1d0b59cd0d3b82c354a8ffb8c3ad (diff)
downloadchrome-ec-18ff8dca1b3e1122b6e527fa1dda3a76846bd3a2.tar.gz
mec1322: Fixed incorrect value passed to I2C unwedge function.
BUG=chrome-os-partner:40175 TEST=Check i2c_unwedge is called with a valid port number by using debug print. BRANCH=none Change-Id: Ibc8e441116441b526c872a9cb33cb252650bca5a Signed-off-by: Kevin K Wong <kevin.k.wong@intel.com> Reviewed-on: https://chromium-review.googlesource.com/272769 Reviewed-by: Shawn N <shawnn@chromium.org>
-rw-r--r--chip/mec1322/i2c.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/chip/mec1322/i2c.c b/chip/mec1322/i2c.c
index 3d86c1c881..badf74749e 100644
--- a/chip/mec1322/i2c.c
+++ b/chip/mec1322/i2c.c
@@ -239,8 +239,8 @@ int i2c_xfer(int port, int slave_addr, const uint8_t *out, int out_size,
get_line_level(controller) & I2C_LINE_SCL_HIGH,
get_line_level(controller) & I2C_LINE_SDA_HIGH);
- /* Attempt to unwedge the controller. */
- i2c_unwedge(controller);
+ /* Attempt to unwedge the port. */
+ i2c_unwedge(port);
/* Bus error, bus busy, or arbitration lost. Try reset. */
reset_controller(controller);